@@ -1,5 +1,5 @@
 from hyperopt import STATUS_OK, Trials, fmin, hp, tpe
-from src.ds_prod.preprocessing import validation_split
+from ds_prod import preprocessing
 from sklearn.metrics import mean_squared_error
 from xgboost import XGBRegressor
 import numpy as np
@@ -7,7 +7,7 @@ import numpy as np
 
 class HOpt:
     def __init__(self, x, y, val_split=0.8):
-        [tr, te] = validation_split(x, val_split)
+        [tr, te] = preprocessing.validation_split(x, val_split)
         self.X_train = x.iloc[tr]
         self.X_val = x.iloc[te]
         self.Y_train = y.iloc[tr]
